==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiWidgets/QGraphicsScene_shell.h <==
#ifndef QGRAPHICSSCENE_SHELL_H
#define QGRAPHICSSCENE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <qtwidgets-config.h>
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsscene.h>
#endif //QT_CONFIG(graphicsview)
#include <QtJambi/QtJambiAPI>
#include <QVarLengthArray>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qline.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qbrush.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpen.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qpolygon.h>
#include <QtGui/qtransform.h>
#include <QtJambiCore/hashes.h>
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsitem.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicssceneevent.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsview.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicswidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(graphicsview)

class QGraphicsScene_shell : public QGraphicsScene, public QtJambiShellInterface
{
public:
    QGraphicsScene_shell(QObject* parent0 = nullptr);
    QGraphicsScene_shell(const QRectF& sceneRect0, QObject* parent1 = nullptr);
    QGraphicsScene_shell(qreal x0, qreal y1, qreal width2, qreal height3, QObject* parent4 = nullptr);
    ~QGraphicsScene_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QGraphicsSceneContextMenuEvent* event0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragLeaveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragMoveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void drawBackground(QPainter* painter0, const QRectF& rect1) override;
    void drawForeground(QPainter* painter0, const QRectF& rect1) override;
    void drawItems(QPainter* painter0, int numItems1, QGraphicsItem** items2, const QStyleOptionGraphicsItem* options3, QWidget* widget4) override;
    void dropEvent(QGraphicsSceneDragDropEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void focusInEvent(QFocusEvent* event0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    void helpEvent(QGraphicsSceneHelpEvent* event0) override;
    void inputMethodEvent(QInputMethodEvent* event0) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void mouseDoubleClickEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseMoveEvent(QGraphicsSceneMouseEvent* event0) override;
    void mousePressEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseReleaseEvent(QGraphicsSceneMouseEvent* event0) override;
    void timerEvent(QTimerEvent* event0) override;
    void wheelEvent(QGraphicsSceneWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGraphicsScene_access : public QGraphicsScene
{
    jboolean __qt_focusNextPrevChild_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean next0);
    void __qt_contextMenuEvent_QGraphicsSceneContextMenuEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dragEnterEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dragLeaveEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dragMoveEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_drawBackground_QPainter_ptr_cref_QRectF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID rect1);
    void __qt_drawForeground_QPainter_ptr_cref_QRectF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID rect1);
    void __qt_drawItems_QPainter_ptr_int_QGraphicsItem_ptr_ptr_const_QStyleOptionGraphicsItem_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, jobjectArray items2, jobjectArray options3, QtJambiNativeID widget4);
    void __qt_dropEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jboolean __qt_eventFilter_QObject_ptr_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID watched0, QtJambiNativeID event1);
    void __qt_focusInEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_focusOutEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_helpEvent_QGraphicsSceneHelpEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_inputMethodEvent_QInputMethodEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jobject __qt_inputMethodQuery_Qt_InputMethodQuery_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint query0) const;
    void __qt_keyPressEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_keyReleaseEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseDoubleClickEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseMoveEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mousePressEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseReleaseEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_wheelEvent_QGraphicsSceneWheelEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
};

#endif // QT_CONFIG(graphicsview)
#endif // QGRAPHICSSCENE_SHELL_H

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiWidgets/QGraphicsScene_shell.h <==
#ifndef QGRAPHICSSCENE_SHELL_H
#define QGRAPHICSSCENE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsscene.h>
#endif //QT_CONFIG(graphicsview)
#include <QtJambi/QtJambiAPI>
#include <QVarLengthArray>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qline.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qbrush.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpen.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qpolygon.h>
#include <QtGui/qtransform.h>
#include <QtJambiCore/hashes.h>
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsitem.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicssceneevent.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsview.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicswidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(graphicsview)

class QGraphicsScene_shell : public QGraphicsScene, public QtJambiShellInterface
{
public:
    QGraphicsScene_shell(QObject* parent0 = nullptr);
    QGraphicsScene_shell(const QRectF& sceneRect0, QObject* parent1 = nullptr);
    QGraphicsScene_shell(qreal x0, qreal y1, qreal width2, qreal height3, QObject* parent4 = nullptr);
    ~QGraphicsScene_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QGraphicsScene_mshell;
    friend class QGraphicsScene_oshell;
};


class QGraphicsScene_mshell : public QGraphicsScene_shell
{
public:
    using QGraphicsScene_shell::QGraphicsScene_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QGraphicsScene_oshell : public QGraphicsScene_mshell
{
public:
    using QGraphicsScene_mshell::QGraphicsScene_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QGraphicsSceneContextMenuEvent* event0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragLeaveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragMoveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void drawBackground(QPainter* painter0, const QRectF& rect1) override;
    void drawForeground(QPainter* painter0, const QRectF& rect1) override;
    void drawItems(QPainter* painter0, int numItems1, QGraphicsItem** items2, const QStyleOptionGraphicsItem* options3, QWidget* widget4) override;
    void dropEvent(QGraphicsSceneDragDropEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    void helpEvent(QGraphicsSceneHelpEvent* event0) override;
    void inputMethodEvent(QInputMethodEvent* event0) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void mouseDoubleClickEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseMoveEvent(QGraphicsSceneMouseEvent* event0) override;
    void mousePressEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseReleaseEvent(QGraphicsSceneMouseEvent* event0) override;
    void timerEvent(QTimerEvent* event0) override;
    void wheelEvent(QGraphicsSceneWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGraphicsScene_access : public QGraphicsScene
{
    void __qt_contextMenuEvent_QGraphicsSceneContextMenuEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dragEnterEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dragLeaveEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dragMoveEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_drawBackground_QPainter_ptr_cref_QRectF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID rect1);
    void __qt_drawForeground_QPainter_ptr_cref_QRectF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID rect1);
    void __qt_drawItems_QPainter_ptr_int_QGraphicsItem_ptr_ptr_const_QStyleOptionGraphicsItem_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, jobjectArray items2, jobjectArray options3, QtJambiNativeID widget4);
    void __qt_dropEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jboolean __qt_eventFilter_QObject_ptr_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID watched0, QtJambiNativeID event1);
    void __qt_focusInEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jboolean __qt_focusNextPrevChild_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean next0);
    void __qt_focusOutEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_helpEvent_QGraphicsSceneHelpEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_inputMethodEvent_QInputMethodEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jobject __qt_inputMethodQuery_Qt_InputMethodQuery_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint query0) const;
    void __qt_keyPressEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_keyReleaseEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseDoubleClickEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseMoveEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mousePressEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseReleaseEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_wheelEvent_QGraphicsSceneWheelEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
};

#endif // QT_CONFIG(graphicsview)
#endif // QGRAPHICSSCENE_SHELL_H
